Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Runner ¶
type Runner struct {
Works []Work // Works holds the list of work items to be executed.
// contains filtered or unexported fields
}
Runner manages and executes a set of Work items.
type Work ¶
type Work struct {
Name string // Name identifies the work item.
Fn Func // Fn is the function to execute.
NoOfWorkers int // NoOfWorkers specifies the number of concurrent workers for this work item.
ExecInterval time.Duration // ExecInterval is the interval between executions of the work function.
Timeout time.Duration // Timeout is the maximum duration allowed for the work function to complete.
}
Work defines a unit of work to be executed by the Runner.
Click to show internal directories.
Click to hide internal directories.